@@ -13,11 +13,14 @@
 # limitations under the License.
 import tensorflow as tf
 
+from keras_cv.layers.preprocessing.base_image_augmentation_layer import (
+    BaseImageAugmentationLayer,
+)
 from keras_cv.utils import preprocessing
 
 
 @tf.keras.utils.register_keras_serializable(package="keras_cv")
-class RandomHue(tf.keras.__internal__.layers.BaseImageAugmentationLayer):
+class RandomHue(BaseImageAugmentationLayer):
     """Randomly adjusts the hue on given images.
 
     This layer will randomly increase/reduce the hue for the input RGB
@@ -52,15 +55,15 @@ class RandomHue(tf.keras.__internal__.layers.BaseImageAugmentationLayer):
         self.value_range = value_range
         self.seed = seed
 
-    def get_random_transformation(self, image=None, label=None, bounding_box=None):
-        del image, label, bounding_box
+    def get_random_transformation(self, image=None, label=None, bounding_boxes=None):
+        del image, label, bounding_boxes
         invert = preprocessing.random_inversion(self._random_generator)
         # We must scale self.factor() to the range [-0.5, 0.5].  This is because the
         # tf.image operation performs rotation on the hue saturation value orientation.
         # This can be thought of as an angle in the range [-180, 180]
         return invert * self.factor() * 0.5
 
-    def augment_image(self, image, transformation=None):
+    def augment_image(self, image, transformation=None, **kwargs):
         image = preprocessing.transform_value_range(image, self.value_range, (0, 1))
         # tf.image.adjust_hue expects floats to be in range [0, 1]
         image = tf.image.adjust_hue(image, delta=transformation)
@@ -69,7 +72,7 @@ class RandomHue(tf.keras.__internal__.layers.BaseImageAugmentationLayer):
         image = preprocessing.transform_value_range(image, (0, 1), self.value_range)
         return image
 
-    def augment_label(self, label, transformation=None):
+    def augment_label(self, label, transformation=None, **kwargs):
         return label
 
     def get_config(self):
