@@ -20,8 +20,8 @@ from keras_cv.layers import regularization
 
 
 def custom_compare(obj1, obj2):
-    if isinstance(obj1, core.FactorSampler):
-        return obj1.get_config() == obj2.get_config()
+    if isinstance(obj1, (core.FactorSampler, tf.keras.layers.Layer)):
+        return config_equals(obj1.get_config(), obj2.get_config())
     else:
         return obj1 == obj2
 
@@ -98,20 +98,12 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         (
             "RandomAugmentationPipeline",
             preprocessing.RandomAugmentationPipeline,
-            {
-                "layers": [],
-                "augmentations_per_image": 1,
-                "rate": 1.0,
-            },
+            {"layers": [], "augmentations_per_image": 1, "rate": 1.0},
         ),
         (
             "RandomChoice",
             preprocessing.RandomChoice,
-            {
-                "layers": [],
-                "seed": 3,
-                "auto_vectorize": False,
-            },
+            {"layers": [], "seed": 3, "auto_vectorize": False},
         ),
         (
             "RandomColorJitter",
@@ -125,13 +117,32 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
                 "seed": 1,
             },
         ),
+        (
+            "RandomResizedCrop",
+            preprocessing.RandomResizedCrop,
+            {
+                "target_size": (224, 224),
+                "crop_area_factor": (0.08, 1.0),
+                "aspect_ratio_factor": (3.0 / 4.0, 4.0 / 3.0),
+                "interpolation": "bilinear",
+                "seed": 1,
+            },
+        ),
         (
             "DropBlock2D",
             regularization.DropBlock2D,
+            {"rate": 0.1, "block_size": (7, 7), "seed": 1234},
+        ),
+        (
+            "StochasticDepth",
+            regularization.StochasticDepth,
+            {"rate": 0.1},
+        ),
+        (
+            "DropPath",
+            regularization.DropPath,
             {
-                "rate": 0.1,
-                "block_size": (7, 7),
-                "seed": 1234,
+                "rate": 0.2,
             },
         ),
         (
@@ -143,6 +154,23 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
                 "seed": 1234,
             },
         ),
+        (
+            "RandomJpegQuality",
+            preprocessing.RandomJpegQuality,
+            {"factor": (75, 100)},
+        ),
+        (
+            "AugMix",
+            preprocessing.AugMix,
+            {
+                "value_range": (0, 255),
+                "severity": 0.3,
+                "num_chains": 3,
+                "chain_depth": -1,
+                "alpha": 1.0,
+                "seed": 1,
+            },
+        ),
     )
     def test_layer_serialization(self, layer_cls, init_args):
         layer = layer_cls(**init_args)
